@@ -11,11 +11,9 @@ per-file-ignores = __init__.py: F401, F403
 CONFIG_FILE_NAME_RADON = 'radon.cfg'
 CONFIG_FILE_CONTENT_RADON = '''[radon]
 cc_min = C
-exclude = */venv/*
 '''
 
 # bandit
 CONFIG_FILE_NAME_BANDIT = '.bandit'
 CONFIG_FILE_CONTENT_BANDIT = '''[bandit]
-exclude: */venv/*
 '''
